/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __LINKED_MAPS_SKEL_H__
#define __LINKED_MAPS_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct linked_maps {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *map1;
		struct bpf_map *map_weak;
		struct bpf_map *map2;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *handler_enter1;
		struct bpf_program *handler_enter2;
		struct bpf_program *handler_exit1;
		struct bpf_program *handler_exit2;
	} progs;
	struct {
		struct bpf_link *handler_enter1;
		struct bpf_link *handler_enter2;
		struct bpf_link *handler_exit1;
		struct bpf_link *handler_exit2;
	} links;
	struct linked_maps__bss {
		int output_first1;
		int output_second1;
		int output_weak1;
		int output_first2;
		int output_second2;
		int output_weak2;
	} *bss;
};

static void
linked_maps__destroy(struct linked_maps *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
linked_maps__create_skeleton(struct linked_maps *obj);

static inline struct linked_maps *
linked_maps__open_opts(const struct bpf_object_open_opts *opts)
{
	struct linked_maps *obj;
	int err;

	obj = (struct linked_maps *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = linked_maps__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	linked_maps__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct linked_maps *
linked_maps__open(void)
{
	return linked_maps__open_opts(NULL);
}

static inline int
linked_maps__load(struct linked_maps *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct linked_maps *
linked_maps__open_and_load(void)
{
	struct linked_maps *obj;
	int err;

	obj = linked_maps__open();
	if (!obj)
		return NULL;
	err = linked_maps__load(obj);
	if (err) {
		linked_maps__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
linked_maps__attach(struct linked_maps *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
linked_maps__detach(struct linked_maps *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *linked_maps__elf_bytes(size_t *sz);

static inline int
linked_maps__create_skeleton(struct linked_maps *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		goto err;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "linked_maps";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 4;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "map1";
	s->maps[0].map = &obj->maps.map1;

	s->maps[1].name = "map_weak";
	s->maps[1].map = &obj->maps.map_weak;

	s->maps[2].name = "map2";
	s->maps[2].map = &obj->maps.map2;

	s->maps[3].name = "linked_m.bss";
	s->maps[3].map = &obj->maps.bss;
	s->maps[3].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 4;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "handler_enter1";
	s->progs[0].prog = &obj->progs.handler_enter1;
	s->progs[0].link = &obj->links.handler_enter1;

	s->progs[1].name = "handler_enter2";
	s->progs[1].prog = &obj->progs.handler_enter2;
	s->progs[1].link = &obj->links.handler_enter2;

	s->progs[2].name = "handler_exit1";
	s->progs[2].prog = &obj->progs.handler_exit1;
	s->progs[2].link = &obj->links.handler_exit1;

	s->progs[3].name = "handler_exit2";
	s->progs[3].prog = &obj->progs.handler_exit2;
	s->progs[3].link = &obj->links.handler_exit2;

	s->data = (void *)linked_maps__elf_bytes(&s->data_sz);

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -ENOMEM;
}

static inline const void *linked_maps__elf_bytes(size_t *sz)
{
	*sz = 7024;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x70\x18\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0c\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x72\x61\
\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x72\x61\x77\x5f\x74\
\x70\x2f\x73\x79\x73\x5f\x65\x78\x69\x74\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\
\x6d\x61\x70\x73\0\x2e\x62\x73\x73\0\x6c\x69\x6e\x6b\x65\x64\x5f\x6d\x61\x70\
\x73\x31\x2e\x63\0\x4c\x42\x42\x31\x5f\x32\0\x4c\x42\x42\x31\x5f\x34\0\x4c\x42\
\x42\x31\x5f\x36\0\x68\x61\x6e\x64\x6c\x65\x72\x5f\x65\x6e\x74\x65\x72\x31\0\
\x6d\x61\x70\x31\0\x6d\x61\x70\x32\0\x6d\x61\x70\x5f\x77\x65\x61\x6b\0\x68\x61\
\x6e\x64\x6c\x65\x72\x5f\x65\x78\x69\x74\x31\0\x6f\x75\x74\x70\x75\x74\x5f\x66\
\x69\x72\x73\x74\x31\0\x6f\x75\x74\x70\x75\x74\x5f\x73\x65\x63\x6f\x6e\x64\x31\
\0\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x31\0\x4c\x49\x43\x45\x4e\x53\
\x45\0\x6c\x69\x6e\x6b\x65\x64\x5f\x6d\x61\x70\x73\x32\x2e\x63\0\x68\x61\x6e\
\x64\x6c\x65\x72\x5f\x65\x6e\x74\x65\x72\x32\0\x68\x61\x6e\x64\x6c\x65\x72\x5f\
\x65\x78\x69\x74\x32\0\x6f\x75\x74\x70\x75\x74\x5f\x66\x69\x72\x73\x74\x32\0\
\x6f\x75\x74\x70\x75\x74\x5f\x73\x65\x63\x6f\x6e\x64\x32\0\x6f\x75\x74\x70\x75\
\x74\x5f\x77\x65\x61\x6b\x32\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\x2f\x73\
\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\x2f\
\x73\x79\x73\x5f\x65\x78\x69\x74\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\
\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x45\0\0\0\x04\0\xf1\
\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x54\0\0\0\0\0\
\x04\0\x70\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5b\0\0\0\0\0\x04\0\xc0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x62\0\0\0\0\0\x04\0\x10\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x69\0\
\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\x08\x01\0\0\0\0\0\0\x78\0\0\0\x11\0\x06\0\0\0\
\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x7d\0\0\0\x11\0\x06\0\x40\0\0\0\0\0\0\0\x20\0\0\
\0\0\0\0\0\x82\0\0\0\x21\0\x06\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x8b\0\0\0\
\x12\0\x04\0\0\0\0\0\0\0\0\0\x20\x01\0\0\0\0\0\0\x99\0\0\0\x11\0\x07\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\0\0\0\0\xa7\0\0\0\x11\0\x07\0\x04\0\0\0\0\0\0\0\x04\0\0\0\0\
\0\0\0\xb6\0\0\0\x11\0\x07\0\x08\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xc3\0\0\0\x11\
\0\x05\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xcb\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x54\0\0\0\0\0\x04\0\x90\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x5b\0\0\0\0\0\x04\0\xe0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x62\0\0\0\0\0\x04\0\
\x30\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xda\0\0\0\x12\0\x03\0\x08\x01\0\0\0\0\0\0\
\x08\x01\0\0\0\0\0\0\xe9\0\0\0\x12\0\x04\0\x20\x01\0\0\0\0\0\0\x20\x01\0\0\0\0\
\0\0\xf7\0\0\0\x11\0\x07\0\x0c\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x05\x01\0\0\x11\
\0\x07\0\x10\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x14\x01\0\0\x11\0\x07\0\x14\0\0\0\
\0\0\0\0\x04\0\0\0\0\0\0\0\xb4\x01\0\0\x01\0\0\0\x63\x1a\xfc\xff\0\0\0\0\x63\
\x1a\xf8\xff\0\0\0\0\xb7\x01\0\0\x01\0\0\0\x7b\x1a\xf0\xff\0\0\0\0\xb7\x01\0\0\
\xe8\x03\0\0\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf0\xff\
\xff\xff\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\xbf\xa6\0\0\0\0\0\0\x07\
\x06\0\0\xfc\xff\xff\xff\xbf\xa7\0\0\0\0\0\0\x07\x07\0\0\xf8\xff\xff\xff\x18\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x62\0\0\0\0\0\0\xbf\x73\0\0\0\0\0\0\xb7\
\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\
\x62\0\0\0\0\0\0\xbf\x73\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\
\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb4\x01\0\0\x02\0\0\0\x63\x1a\xfc\xff\0\0\
\0\0\x63\x1a\xf8\xff\0\0\0\0\xb7\x01\0\0\x02\0\0\0\x7b\x1a\xf0\xff\0\0\0\0\xb7\
\x01\0\0\xd0\x07\0\0\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\
\xf0\xff\xff\xff\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\xbf\xa6\0\0\0\0\
\0\0\x07\x06\0\0\xfc\xff\xff\xff\xbf\xa7\0\0\0\0\0\0\x07\x07\0\0\xf8\xff\xff\
\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x62\0\0\0\0\0\0\xbf\x73\0\0\0\0\0\
\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xbf\x62\0\0\0\0\0\0\xbf\x73\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\
\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb4\x01\0\0\x02\0\0\0\x63\x1a\xfc\xff\0\
\0\0\0\xb7\x01\0\0\x02\0\0\0\x7b\x1a\xf0\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\
\x02\0\0\xf0\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\
\0\x15\0\x04\0\0\0\0\0\x79\x01\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x63\x12\0\0\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xfc\xff\xff\xff\x18\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\x15\0\x04\0\0\0\0\0\x61\x01\0\0\
\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xbf\xa2\0\0\0\
\0\0\0\x07\x02\0\0\xfc\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\
\0\x01\0\0\0\x15\0\x04\0\0\0\0\0\x61\x01\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb4\x01\0\0\
\x01\0\0\0\x63\x1a\xfc\xff\0\0\0\0\xb7\x01\0\0\x01\0\0\0\x7b\x1a\xf0\xff\0\0\0\
\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf0\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x85\0\0\0\x01\0\0\0\x15\0\x04\0\0\0\0\0\x79\x01\0\0\0\0\0\0\x18\x02\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\
\xfc\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\x15\0\
\x04\0\0\0\0\0\x61\x01\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\
\0\0\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xfc\xff\xff\xff\x18\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\x15\0\x04\0\0\0\0\0\x61\x01\0\0\0\0\0\0\
\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\
\0\0\0\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x58\0\0\0\0\0\0\0\
\x01\0\0\0\x08\0\0\0\x98\0\0\0\0\0\0\0\x01\0\0\0\x09\0\0\0\xc8\0\0\0\0\0\0\0\
\x01\0\0\0\x0a\0\0\0\x60\x01\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\xa0\x01\0\0\0\0\0\
\0\x01\0\0\0\x09\0\0\0\xd0\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x30\0\0\0\0\0\0\
\0\x01\0\0\0\x08\0\0\0\x58\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x80\0\0\0\0\0\0\0\
\x01\0\0\0\x09\0\0\0\xa8\0\0\0\0\0\0\0\x01\0\0\0\x0d\0\0\0\xd0\0\0\0\0\0\0\0\
\x01\0\0\0\x0a\0\0\0\xf8\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\x50\x01\0\0\0\0\0\0\
\x01\0\0\0\x08\0\0\0\x78\x01\0\0\0\0\0\0\x01\0\0\0\x16\0\0\0\xa0\x01\0\0\0\0\0\
\0\x01\0\0\0\x09\0\0\0\xc8\x01\0\0\0\0\0\0\x01\0\0\0\x17\0\0\0\xf0\x01\0\0\0\0\
\0\0\x01\0\0\0\x0a\0\0\0\x18\x02\0\0\0\0\0\0\x01\0\0\0\x18\0\0\0\x9f\xeb\x01\0\
\x18\0\0\0\0\0\0\0\x40\x04\0\0\x40\x04\0\0\x08\x06\0\0\0\0\0\0\0\0\0\x02\x03\0\
\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\
\0\0\x04\0\0\0\x01\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\
\x02\x06\0\0\0\x19\0\0\0\x01\0\0\x04\x08\0\0\0\x20\0\0\0\x07\0\0\0\0\0\0\0\x22\
\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\x01\0\0\0\0\0\0\0\x02\x09\0\0\0\x27\0\0\0\
\x01\0\0\x04\x08\0\0\0\x20\0\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x0b\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x10\0\0\0\0\0\0\0\x04\0\0\x04\
\x20\0\0\0\x30\0\0\0\x01\0\0\0\0\0\0\0\x35\0\0\0\x05\0\0\0\x40\0\0\0\x39\0\0\0\
\x08\0\0\0\x80\0\0\0\x3f\0\0\0\x0a\0\0\0\xc0\0\0\0\x4b\0\0\0\0\0\0\x0e\x0c\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x0f\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\
\x04\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\
\x30\0\0\0\x0e\0\0\0\0\0\0\0\x35\0\0\0\x10\0\0\0\x40\0\0\0\x39\0\0\0\x10\0\0\0\
\x80\0\0\0\x3f\0\0\0\x0a\0\0\0\xc0\0\0\0\x50\0\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\x02\x14\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\
\x08\0\0\0\x59\0\0\0\0\0\0\x08\x16\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x3f\0\0\
\0\x13\0\0\0\0\0\0\0\x35\0\0\0\x10\0\0\0\x40\0\0\0\x39\0\0\0\x10\0\0\0\x80\0\0\
\0\x30\0\0\0\x0e\0\0\0\xc0\0\0\0\x60\0\0\0\0\0\0\x0e\x23\0\0\0\x01\0\0\0\0\0\0\
\0\0\0\0\x02\x19\0\0\0\x65\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\
\x0d\x02\0\0\0\x78\0\0\0\x18\0\0\0\x7c\0\0\0\x01\0\0\x0c\x1a\0\0\0\x8b\0\0\0\
\x01\0\0\x0c\x1a\0\0\0\x99\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\
\x03\0\0\0\0\x1d\0\0\0\x04\0\0\0\x04\0\0\0\x9e\0\0\0\0\0\0\x0e\x1e\0\0\0\x01\0\
\0\0\xa6\0\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\xb4\0\0\0\0\0\0\x0e\x02\0\0\0\x01\
\0\0\0\xc3\0\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\
\x30\0\0\0\x0e\0\0\0\0\0\0\0\x35\0\0\0\x10\0\0\0\x40\0\0\0\x39\0\0\0\x10\0\0\0\
\x80\0\0\0\x3f\0\0\0\x13\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\x02\x25\0\0\0\xd0\0\0\0\
\0\0\0\x08\x06\0\0\0\0\0\0\0\0\0\0\x02\x27\0\0\0\xd9\0\0\0\0\0\0\x08\x09\0\0\0\
\0\0\0\0\x04\0\0\x04\x20\0\0\0\x3f\0\0\0\x0a\0\0\0\0\0\0\0\x35\0\0\0\x24\0\0\0\
\x40\0\0\0\x39\0\0\0\x26\0\0\0\x80\0\0\0\x30\0\0\0\x01\0\0\0\xc0\0\0\0\xe4\0\0\
\0\x01\0\0\x0c\x1a\0\0\0\xf3\0\0\0\x01\0\0\x0c\x1a\0\0\0\x01\x01\0\0\0\0\0\x0e\
\x02\0\0\0\x01\0\0\0\x0f\x01\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\x1e\x01\0\0\0\0\
\0\x0e\x02\0\0\0\x01\0\0\0\xd4\x05\0\0\x01\0\0\x0f\x04\0\0\0\x1f\0\0\0\0\0\0\0\
\x04\0\0\0\xdc\x05\0\0\x03\0\0\x0f\x80\0\0\0\x0d\0\0\0\0\0\0\0\x20\0\0\0\x12\0\
\0\0\x20\0\0\0\x20\0\0\0\x17\0\0\0\x40\0\0\0\x20\0\0\0\xe2\x05\0\0\x06\0\0\x0f\
\x18\0\0\0\x20\0\0\0\0\0\0\0\x04\0\0\0\x21\0\0\0\x04\0\0\0\x04\0\0\0\x22\0\0\0\
\x08\0\0\0\x04\0\0\0\x2b\0\0\0\x0c\0\0\0\x04\0\0\0\x2c\0\0\0\x10\0\0\0\x04\0\0\
\0\x2d\0\0\0\x14\0\0\0\x04\0\0\0\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\
\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x6d\x79\x5f\x6b\x65\x79\0\
\x78\0\x6c\x6f\x6e\x67\0\x6d\x79\x5f\x76\x61\x6c\x75\x65\0\x74\x79\x70\x65\0\
\x6b\x65\x79\0\x76\x61\x6c\x75\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\
\x73\0\x6d\x61\x70\x31\0\x6d\x61\x70\x5f\x77\x65\x61\x6b\0\x6d\x61\x70\x32\x5f\
\x74\0\x6d\x61\x70\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\
\x20\x6c\x6f\x6e\x67\0\x63\x74\x78\0\x68\x61\x6e\x64\x6c\x65\x72\x5f\x65\x6e\
\x74\x65\x72\x31\0\x68\x61\x6e\x64\x6c\x65\x72\x5f\x65\x78\x69\x74\x31\0\x63\
\x68\x61\x72\0\x4c\x49\x43\x45\x4e\x53\x45\0\x6f\x75\x74\x70\x75\x74\x5f\x66\
\x69\x72\x73\x74\x31\0\x6f\x75\x74\x70\x75\x74\x5f\x73\x65\x63\x6f\x6e\x64\x31\
\0\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x31\0\x6b\x65\x79\x5f\x74\x79\
\x70\x65\0\x76\x61\x6c\x75\x65\x5f\x74\x79\x70\x65\0\x68\x61\x6e\x64\x6c\x65\
\x72\x5f\x65\x6e\x74\x65\x72\x32\0\x68\x61\x6e\x64\x6c\x65\x72\x5f\x65\x78\x69\
\x74\x32\0\x6f\x75\x74\x70\x75\x74\x5f\x66\x69\x72\x73\x74\x32\0\x6f\x75\x74\
\x70\x75\x74\x5f\x73\x65\x63\x6f\x6e\x64\x32\0\x6f\x75\x74\x70\x75\x74\x5f\x77\
\x65\x61\x6b\x32\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\
\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\
\x30\x2d\x31\x36\x32\x2e\x32\x32\x2e\x32\x2e\x65\x6c\x39\x5f\x31\x2f\x6c\x69\
\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x31\x36\x32\x2e\x32\x32\x2e\x32\
\x2e\x65\x6c\x39\x5f\x31\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\
\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\
\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x6c\x69\x6e\x6b\x65\x64\x5f\x6d\x61\
\x70\x73\x31\x2e\x63\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\
\x61\x6e\x64\x6c\x65\x72\x5f\x65\x6e\x74\x65\x72\x31\x29\0\x09\x69\x6e\x74\x20\
\x6b\x65\x79\x20\x3d\x20\x31\x2c\x20\x76\x61\x6c\x20\x3d\x20\x31\x3b\0\x09\x73\
\x74\x72\x75\x63\x74\x20\x6d\x79\x5f\x6b\x65\x79\x20\x6b\x65\x79\x5f\x73\x74\
\x72\x75\x63\x74\x20\x3d\x20\x7b\x20\x2e\x78\x20\x3d\x20\x31\x20\x7d\x3b\0\x09\
\x73\x74\x72\x75\x63\x74\x20\x6d\x79\x5f\x76\x61\x6c\x75\x65\x20\x76\x61\x6c\
\x5f\x73\x74\x72\x75\x63\x74\x20\x3d\x20\x7b\x20\x2e\x78\x20\x3d\x20\x31\x30\
\x30\x30\x20\x7d\x3b\0\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\
\x65\x5f\x65\x6c\x65\x6d\x28\x26\x6d\x61\x70\x31\x2c\x20\x26\x6b\x65\x79\x5f\
\x73\x74\x72\x75\x63\x74\x2c\x20\x26\x76\x61\x6c\x5f\x73\x74\x72\x75\x63\x74\
\x2c\x20\x30\x29\x3b\0\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\
\x65\x5f\x65\x6c\x65\x6d\x28\x26\x6d\x61\x70\x32\x2c\x20\x26\x6b\x65\x79\x2c\
\x20\x26\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\
\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x26\x6d\x61\x70\x5f\x77\x65\
\x61\x6b\x2c\x20\x26\x6b\x65\x79\x2c\x20\x26\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\
\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\
\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x31\x36\
\x32\x2e\x32\x32\x2e\x32\x2e\x65\x6c\x39\x5f\x31\x2f\x6c\x69\x6e\x75\x78\x2d\
\x35\x2e\x31\x34\x2e\x30\x2d\x31\x36\x32\x2e\x32\x32\x2e\x32\x2e\x65\x6c\x39\
\x5f\x31\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\
\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\
\x70\x72\x6f\x67\x73\x2f\x6c\x69\x6e\x6b\x65\x64\x5f\x6d\x61\x70\x73\x32\x2e\
\x63\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\
\x65\x72\x5f\x65\x6e\x74\x65\x72\x32\x29\0\x09\x69\x6e\x74\x20\x6b\x65\x79\x20\
\x3d\x20\x32\x2c\x20\x76\x61\x6c\x20\x3d\x20\x32\x3b\0\x09\x6b\x65\x79\x5f\x74\
\x79\x70\x65\x20\x6b\x65\x79\x5f\x73\x74\x72\x75\x63\x74\x20\x3d\x20\x7b\x20\
\x2e\x78\x20\x3d\x20\x32\x20\x7d\x3b\0\x09\x76\x61\x6c\x75\x65\x5f\x74\x79\x70\
\x65\x20\x76\x61\x6c\x5f\x73\x74\x72\x75\x63\x74\x20\x3d\x20\x7b\x20\x2e\x78\
\x20\x3d\x20\x32\x30\x30\x30\x20\x7d\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\
\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\x72\x5f\x65\x78\x69\x74\x31\x29\0\x09\
\x69\x6e\x74\x20\x6b\x65\x79\x20\x3d\x20\x32\x2c\x20\x2a\x76\x61\x6c\x3b\0\x09\
\x73\x74\x72\x75\x63\x74\x20\x6d\x79\x5f\x6b\x65\x79\x20\x6b\x65\x79\x5f\x73\
\x74\x72\x75\x63\x74\x20\x3d\x20\x7b\x20\x2e\x78\x20\x3d\x20\x32\x20\x7d\x3b\0\
\x09\x76\x61\x6c\x75\x65\x5f\x73\x74\x72\x75\x63\x74\x20\x3d\x20\x62\x70\x66\
\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x6d\
\x61\x70\x31\x2c\x20\x26\x6b\x65\x79\x5f\x73\x74\x72\x75\x63\x74\x29\x3b\0\x09\
\x69\x66\x20\x28\x76\x61\x6c\x75\x65\x5f\x73\x74\x72\x75\x63\x74\x29\0\x09\x09\
\x6f\x75\x74\x70\x75\x74\x5f\x66\x69\x72\x73\x74\x31\x20\x3d\x20\x76\x61\x6c\
\x75\x65\x5f\x73\x74\x72\x75\x63\x74\x2d\x3e\x78\x3b\0\x09\x76\x61\x6c\x20\x3d\
\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\
\x6d\x28\x26\x6d\x61\x70\x32\x2c\x20\x26\x6b\x65\x79\x29\x3b\0\x09\x69\x66\x20\
\x28\x76\x61\x6c\x29\0\x09\x09\x6f\x75\x74\x70\x75\x74\x5f\x73\x65\x63\x6f\x6e\
\x64\x31\x20\x3d\x20\x2a\x76\x61\x6c\x3b\0\x09\x76\x61\x6c\x20\x3d\x20\x62\x70\
\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\
\x6d\x61\x70\x5f\x77\x65\x61\x6b\x2c\x20\x26\x6b\x65\x79\x29\x3b\0\x09\x09\x6f\
\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x31\x20\x3d\x20\x2a\x76\x61\x6c\x3b\0\
\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x68\x61\x6e\x64\x6c\x65\
\x72\x5f\x65\x78\x69\x74\x32\x29\0\x09\x69\x6e\x74\x20\x6b\x65\x79\x20\x3d\x20\
\x31\x2c\x20\x2a\x76\x61\x6c\x3b\0\x09\x6b\x65\x79\x5f\x74\x79\x70\x65\x20\x6b\
\x65\x79\x5f\x73\x74\x72\x75\x63\x74\x20\x3d\x20\x7b\x20\x2e\x78\x20\x3d\x20\
\x31\x20\x7d\x3b\0\x09\x09\x6f\x75\x74\x70\x75\x74\x5f\x66\x69\x72\x73\x74\x32\
\x20\x3d\x20\x76\x61\x6c\x75\x65\x5f\x73\x74\x72\x75\x63\x74\x2d\x3e\x78\x3b\0\
\x09\x09\x6f\x75\x74\x70\x75\x74\x5f\x73\x65\x63\x6f\x6e\x64\x32\x20\x3d\x20\
\x2a\x76\x61\x6c\x3b\0\x09\x09\x6f\x75\x74\x70\x75\x74\x5f\x77\x65\x61\x6b\x32\
\x20\x3d\x20\x2a\x76\x61\x6c\x3b\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\
\x70\x73\0\x2e\x62\x73\x73\0\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\
\x6e\x74\x65\x72\0\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\x78\x69\x74\
\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x34\0\0\0\x34\0\0\0\xd4\x03\0\0\x08\x04\0\0\
\0\0\0\0\x08\0\0\0\xe7\x05\0\0\x02\0\0\0\0\0\0\0\x1b\0\0\0\x08\x01\0\0\x29\0\0\
\0\xf8\x05\0\0\x02\0\0\0\0\0\0\0\x1c\0\0\0\x20\x01\0\0\x2a\0\0\0\x10\0\0\0\xe7\
\x05\0\0\x16\0\0\0\0\0\0\0\x2b\x01\0\0\xb2\x01\0\0\0\xb4\0\0\x08\0\0\0\x2b\x01\
\0\0\xcf\x01\0\0\x06\xc0\0\0\x10\0\0\0\x2b\x01\0\0\xcf\x01\0\0\x0f\xc0\0\0\x20\
\0\0\0\x2b\x01\0\0\xe6\x01\0\0\x10\xc4\0\0\x30\0\0\0\x2b\x01\0\0\x0e\x02\0\0\
\x12\xc8\0\0\x40\0\0\0\x2b\x01\0\0\0\0\0\0\0\0\0\0\x58\0\0\0\x2b\x01\0\0\x3b\
\x02\0\0\x02\xd0\0\0\x80\0\0\0\x2b\x01\0\0\0\0\0\0\0\0\0\0\x98\0\0\0\x2b\x01\0\
\0\x75\x02\0\0\x02\xd4\0\0\xc8\0\0\0\x2b\x01\0\0\xa1\x02\0\0\x02\xd8\0\0\xf8\0\
\0\0\x2b\x01\0\0\xb2\x01\0\0\x05\xb4\0\0\x08\x01\0\0\xd1\x02\0\0\x58\x03\0\0\0\
\x9c\0\0\x10\x01\0\0\xd1\x02\0\0\x75\x03\0\0\x06\xa8\0\0\x18\x01\0\0\xd1\x02\0\
\0\x75\x03\0\0\x0f\xa8\0\0\x28\x01\0\0\xd1\x02\0\0\x8c\x03\0\0\x0b\xac\0\0\x38\
\x01\0\0\xd1\x02\0\0\xaf\x03\0\0\x0d\xb0\0\0\x48\x01\0\0\xd1\x02\0\0\0\0\0\0\0\
\0\0\0\x60\x01\0\0\xd1\x02\0\0\x3b\x02\0\0\x02\xb8\0\0\x88\x01\0\0\xd1\x02\0\0\
\0\0\0\0\0\0\0\0\xa0\x01\0\0\xd1\x02\0\0\x75\x02\0\0\x02\xbc\0\0\xd0\x01\0\0\
\xd1\x02\0\0\xa1\x02\0\0\x02\xc0\0\0\0\x02\0\0\xd1\x02\0\0\x58\x03\0\0\x05\x9c\
\0\0\xf8\x05\0\0\x26\0\0\0\0\0\0\0\x2b\x01\0\0\xd7\x03\0\0\0\xf0\0\0\x08\0\0\0\
\x2b\x01\0\0\xf3\x03\0\0\x06\xfc\0\0\x18\0\0\0\x2b\x01\0\0\x07\x04\0\0\x10\0\
\x01\0\x28\0\0\0\x2b\x01\0\0\0\0\0\0\0\0\0\0\x30\0\0\0\x2b\x01\0\0\x2f\x04\0\0\
\x11\x0c\x01\0\x48\0\0\0\x2b\x01\0\0\x68\x04\0\0\x06\x10\x01\0\x50\0\0\0\x2b\
\x01\0\0\x7b\x04\0\0\x21\x14\x01\0\x58\0\0\0\x2b\x01\0\0\x7b\x04\0\0\x11\x14\
\x01\0\x78\0\0\0\x2b\x01\0\0\0\0\0\0\0\0\0\0\x80\0\0\0\x2b\x01\0\0\x9e\x04\0\0\
\x08\x1c\x01\0\x98\0\0\0\x2b\x01\0\0\xc7\x04\0\0\x06\x20\x01\0\xa0\0\0\0\x2b\
\x01\0\0\xd1\x04\0\0\x14\x24\x01\0\xa8\0\0\0\x2b\x01\0\0\xd1\x04\0\0\x12\x24\
\x01\0\xc8\0\0\0\x2b\x01\0\0\0\0\0\0\0\0\0\0\xd0\0\0\0\x2b\x01\0\0\xea\x04\0\0\
\x08\x2c\x01\0\xe8\0\0\0\x2b\x01\0\0\xc7\x04\0\0\x06\x30\x01\0\xf0\0\0\0\x2b\
\x01\0\0\x17\x05\0\0\x12\x34\x01\0\xf8\0\0\0\x2b\x01\0\0\x17\x05\0\0\x10\x34\
\x01\0\x10\x01\0\0\x2b\x01\0\0\xd7\x03\0\0\x05\xf0\0\0\x20\x01\0\0\xd1\x02\0\0\
\x2e\x05\0\0\0\xd8\0\0\x28\x01\0\0\xd1\x02\0\0\x4a\x05\0\0\x06\xe4\0\0\x38\x01\
\0\0\xd1\x02\0\0\x5e\x05\0\0\x0b\xe8\0\0\x48\x01\0\0\xd1\x02\0\0\0\0\0\0\0\0\0\
\0\x50\x01\0\0\xd1\x02\0\0\x2f\x04\0\0\x11\xf4\0\0\x68\x01\0\0\xd1\x02\0\0\x68\
\x04\0\0\x06\xf8\0\0\x70\x01\0\0\xd1\x02\0\0\x81\x05\0\0\x21\xfc\0\0\x78\x01\0\
\0\xd1\x02\0\0\x81\x05\0\0\x11\xfc\0\0\x98\x01\0\0\xd1\x02\0\0\0\0\0\0\0\0\0\0\
\xa0\x01\0\0\xd1\x02\0\0\x9e\x04\0\0\x08\x04\x01\0\xb8\x01\0\0\xd1\x02\0\0\xc7\
\x04\0\0\x06\x08\x01\0\xc0\x01\0\0\xd1\x02\0\0\xa4\x05\0\0\x14\x0c\x01\0\xc8\
\x01\0\0\xd1\x02\0\0\xa4\x05\0\0\x12\x0c\x01\0\xe8\x01\0\0\xd1\x02\0\0\0\0\0\0\
\0\0\0\0\xf0\x01\0\0\xd1\x02\0\0\xea\x04\0\0\x08\x14\x01\0\x08\x02\0\0\xd1\x02\
\0\0\xc7\x04\0\0\x06\x18\x01\0\x10\x02\0\0\xd1\x02\0\0\xbd\x05\0\0\x12\x1c\x01\
\0\x18\x02\0\0\xd1\x02\0\0\xbd\x05\0\0\x10\x1c\x01\0\x30\x02\0\0\xd1\x02\0\0\
\x2e\x05\0\0\x05\xd8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x58\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x98\x01\0\0\0\0\0\0\x58\x02\0\0\0\0\0\0\x01\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\x03\0\0\0\0\0\0\x10\x02\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\x40\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x32\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x40\x08\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x3a\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x48\x08\0\0\0\
\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\
\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x08\0\0\0\0\0\0\x18\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x21\x01\0\0\x09\0\
\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x08\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\
\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x36\x01\0\0\x09\0\0\0\
\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x09\0\0\0\0\0\0\xc0\0\0\0\0\0\0\0\x02\0\
\0\0\x04\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x4a\x01\0\0\x01\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\x09\0\0\0\0\0\0\x60\x0a\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x4f\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x48\x14\0\0\0\0\0\0\x28\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0";
}

#endif /* __LINKED_MAPS_SKEL_H__ */
