/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TAG_SKEL_H__
#define __TAG_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct tag {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *hashmap1;
		struct bpf_map *rodata;
	} maps;
	struct {
		struct bpf_program *sub;
	} progs;
	struct {
		struct bpf_link *sub;
	} links;
	struct tag__rodata {
		bool skip_tests;
	} *rodata;
};

static void
tag__destroy(struct tag *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
tag__create_skeleton(struct tag *obj);

static inline struct tag *
tag__open_opts(const struct bpf_object_open_opts *opts)
{
	struct tag *obj;
	int err;

	obj = (struct tag *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = tag__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	tag__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct tag *
tag__open(void)
{
	return tag__open_opts(NULL);
}

static inline int
tag__load(struct tag *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct tag *
tag__open_and_load(void)
{
	struct tag *obj;
	int err;

	obj = tag__open();
	if (!obj)
		return NULL;
	err = tag__load(obj);
	if (err) {
		tag__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
tag__attach(struct tag *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
tag__detach(struct tag *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *tag__elf_bytes(size_t *sz);

static inline int
tag__create_skeleton(struct tag *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		goto err;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "tag";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "hashmap1";
	s->maps[0].map = &obj->maps.hashmap1;

	s->maps[1].name = "tag.rodata";
	s->maps[1].map = &obj->maps.rodata;
	s->maps[1].mmaped = (void **)&obj->rodata;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "sub";
	s->progs[0].prog = &obj->progs.sub;
	s->progs[0].link = &obj->links.sub;

	s->data = (void *)tag__elf_bytes(&s->data_sz);

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -ENOMEM;
}

static inline const void *tag__elf_bytes(size_t *sz)
{
	*sz = 2768;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x10\x08\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0b\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x74\
\x65\x78\x74\0\x66\x65\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\
\x79\x5f\x74\x65\x73\x74\x31\0\x2e\x72\x6f\x64\x61\x74\x61\0\x2e\x6d\x61\x70\
\x73\0\x74\x61\x67\x2e\x63\0\x66\x6f\x6f\0\x73\x75\x62\0\x68\x61\x73\x68\x6d\
\x61\x70\x31\0\x73\x6b\x69\x70\x5f\x74\x65\x73\x74\x73\0\x2e\x72\x65\x6c\x2e\
\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\
\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\x74\x31\0\x2e\x42\x54\x46\0\x2e\x42\
\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x3d\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x43\0\0\0\x02\0\x03\0\0\0\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x47\0\0\0\
\x12\0\x04\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x4b\0\0\0\x11\0\x06\0\0\0\0\0\0\
\0\0\0\x20\0\0\0\0\0\0\0\x54\0\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\
\0\x63\x1a\xf8\xff\0\0\0\0\x63\x1a\xf4\xff\0\0\0\0\x63\x1a\xf0\xff\0\0\0\0\xb7\
\x01\0\0\0\0\0\0\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf0\
\xff\xff\xff\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\x95\0\0\0\0\0\0\0\
\x79\x11\0\0\0\0\0\0\x85\x10\0\0\xff\xff\xff\xff\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x48\0\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x08\0\0\0\0\0\0\0\x0a\0\0\0\x02\
\0\0\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\xbc\x02\0\0\xbc\x02\0\0\xcf\x01\0\0\0\0\
\0\0\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\
\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\
\0\0\0\0\0\0\0\0\0\0\x02\x06\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\
\0\x03\0\0\0\0\0\0\0\0\0\0\x02\x08\0\0\0\x19\0\0\0\x03\0\0\x04\x0c\0\0\0\x1f\0\
\0\0\x02\0\0\0\0\0\0\0\x21\0\0\0\x02\0\0\0\x20\0\0\0\x23\0\0\0\x02\0\0\0\x40\0\
\0\0\x25\0\0\0\0\0\0\x11\x08\0\0\0\xff\xff\xff\xff\x2a\0\0\0\0\0\0\x11\x08\0\0\
\0\xff\xff\xff\xff\x25\0\0\0\0\0\0\x11\x08\0\0\0\x01\0\0\0\x2a\0\0\0\0\0\0\x11\
\x08\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x0e\0\0\0\x2f\0\0\0\0\0\0\x08\x11\0\0\0\
\x25\0\0\0\0\0\0\x11\x0e\0\0\0\xff\xff\xff\xff\x2a\0\0\0\0\0\0\x11\x0e\0\0\0\
\xff\xff\xff\xff\0\0\0\0\x02\0\0\x04\x08\0\0\0\x1f\0\0\0\x02\0\0\0\0\0\0\0\x21\
\0\0\0\x02\0\0\0\x20\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x37\0\0\0\x01\0\0\0\0\
\0\0\0\x3c\0\0\0\x05\0\0\0\x40\0\0\0\x48\0\0\0\x07\0\0\0\x80\0\0\0\x4c\0\0\0\
\x0d\0\0\0\xc0\0\0\0\x52\0\0\0\0\0\0\x0e\x12\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\
\x15\0\0\0\x5b\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\x0d\x02\0\0\
\0\x6e\0\0\0\x14\0\0\0\x72\0\0\0\x01\0\0\x0c\x16\0\0\0\0\0\0\0\x01\0\0\x0d\x02\
\0\0\0\x76\0\0\0\x02\0\0\0\x78\0\0\0\0\0\0\x0c\x18\0\0\0\x25\0\0\0\0\0\0\x11\
\x19\0\0\0\0\0\0\0\x2a\0\0\0\0\0\0\x11\x19\0\0\0\0\0\0\0\x25\0\0\0\0\0\0\x11\
\x19\0\0\0\xff\xff\xff\xff\x2a\0\0\0\0\0\0\x11\x19\0\0\0\xff\xff\xff\xff\0\0\0\
\0\0\0\0\x0a\x1f\0\0\0\0\0\0\0\0\0\0\x09\x20\0\0\0\x7c\0\0\0\0\0\0\x08\x21\0\0\
\0\x81\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x04\x87\0\0\0\0\0\0\x0e\x1e\0\0\0\x01\
\0\0\0\x25\0\0\0\0\0\0\x11\x22\0\0\0\xff\xff\xff\xff\x2a\0\0\0\0\0\0\x11\x22\0\
\0\0\xff\xff\xff\xff\xa3\x01\0\0\x01\0\0\x0f\x01\0\0\0\x22\0\0\0\0\0\0\0\x01\0\
\0\0\xab\x01\0\0\x01\0\0\x0f\x20\0\0\0\x13\0\0\0\0\0\0\0\x20\0\0\0\0\x69\x6e\
\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\
\x5f\0\x6b\x65\x79\x5f\x74\0\x61\0\x62\0\x63\0\x74\x61\x67\x31\0\x74\x61\x67\
\x32\0\x76\x61\x6c\x75\x65\x5f\x74\0\x74\x79\x70\x65\0\x6d\x61\x78\x5f\x65\x6e\
\x74\x72\x69\x65\x73\0\x6b\x65\x79\0\x76\x61\x6c\x75\x65\0\x68\x61\x73\x68\x6d\
\x61\x70\x31\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\
\x6e\x67\0\x63\x74\x78\0\x73\x75\x62\0\x78\0\x66\x6f\x6f\0\x62\x6f\x6f\x6c\0\
\x5f\x42\x6f\x6f\x6c\0\x73\x6b\x69\x70\x5f\x74\x65\x73\x74\x73\0\x2f\x62\x75\
\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\
\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x31\x36\x32\x2e\x32\
\x32\x2e\x32\x2e\x65\x6c\x39\x5f\x31\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\
\x34\x2e\x30\x2d\x31\x36\x32\x2e\x32\x32\x2e\x32\x2e\x65\x6c\x39\x5f\x31\x2e\
\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\
\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\
\x67\x73\x2f\x74\x61\x67\x2e\x63\0\x09\x6b\x65\x79\x2e\x61\x20\x3d\x20\x6b\x65\
\x79\x2e\x62\x20\x3d\x20\x6b\x65\x79\x2e\x63\x20\x3d\x20\x78\x3b\0\x09\x76\x61\
\x6c\x75\x65\x5f\x74\x20\x76\x61\x6c\x20\x3d\x20\x7b\x7d\x3b\0\x09\x62\x70\x66\
\x5f\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x26\x68\
\x61\x73\x68\x6d\x61\x70\x31\x2c\x20\x26\x6b\x65\x79\x2c\x20\x26\x76\x61\x6c\
\x2c\x20\x30\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x30\x3b\0\x69\x6e\x74\
\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x75\x62\x2c\x20\x69\x6e\x74\x20\
\x78\x29\0\x09\x72\x65\x74\x75\x72\x6e\x20\x66\x6f\x6f\x28\x78\x29\x3b\0\x2e\
\x72\x6f\x64\x61\x74\x61\0\x2e\x6d\x61\x70\x73\0\x2e\x74\x65\x78\x74\0\x66\x65\
\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\
\x74\x31\0\0\0\0\0\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x24\0\0\0\x24\0\0\0\xb4\0\
\0\0\xd8\0\0\0\0\0\0\0\x08\0\0\0\xb1\x01\0\0\x01\0\0\0\0\0\0\0\x19\0\0\0\xb7\
\x01\0\0\x01\0\0\0\0\0\0\0\x17\0\0\0\x10\0\0\0\xb1\x01\0\0\x07\0\0\0\0\0\0\0\
\x92\0\0\0\x10\x01\0\0\x18\xb4\0\0\x08\0\0\0\x92\0\0\0\x10\x01\0\0\x10\xb4\0\0\
\x10\0\0\0\x92\0\0\0\x10\x01\0\0\x08\xb4\0\0\x20\0\0\0\x92\0\0\0\x2c\x01\0\0\
\x0a\xac\0\0\x30\0\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\x48\0\0\0\x92\0\0\0\x3f\x01\0\
\0\x02\xb8\0\0\x68\0\0\0\x92\0\0\0\x6f\x01\0\0\x02\xbc\0\0\xb7\x01\0\0\x03\0\0\
\0\0\0\0\0\x92\0\0\0\x7a\x01\0\0\x05\xcc\0\0\x08\0\0\0\x92\0\0\0\x93\x01\0\0\
\x09\xd4\0\0\x10\0\0\0\x92\0\0\0\x7a\x01\0\0\x05\xcc\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x40\0\0\0\0\0\0\0\x93\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\0\0\0\0\0\
\0\0\xc0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\
\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x98\x01\0\0\0\0\0\0\x70\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x17\0\0\0\x01\
\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x02\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x2f\0\0\0\x01\0\0\0\x02\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x02\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x37\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x30\x02\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x5f\0\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x50\x02\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\x69\0\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\
\x02\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x02\0\0\0\
\0\0\0\xa3\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x8a\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x07\0\0\0\0\0\0\xf8\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";
}

#endif /* __TAG_SKEL_H__ */
